==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/glue/kotlin/inputs/JobNotificationPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.glue.kotlin.inputs

import com.pulumi.aws.glue.inputs.JobNotificationPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property notifyDelayAfter After a job run starts, the number of minutes to wait before sending a job run delay notification.
 */
public data class JobNotificationPropertyArgs(
    public val notifyDelayAfter: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.glue.inputs.JobNotificationPropertyArgs> {
    override fun toJava(): com.pulumi.aws.glue.inputs.JobNotificationPropertyArgs =
        com.pulumi.aws.glue.inputs.JobNotificationPropertyArgs.builder()
            .notifyDelayAfter(notifyDelayAfter?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [JobNotificationPropertyArgs].
 */
@PulumiTagMarker
public class JobNotificationPropertyArgsBuilder internal constructor() {
    private var notifyDelayAfter: Output<Int>? = null

    /**
     * @param value After a job run starts, the number of minutes to wait before sending a job run delay notification.
     */
    @JvmName("qvytkfdokifhsnnb")
    public suspend fun notifyDelayAfter(`value`: Output<Int>) {
        this.notifyDelayAfter = value
    }

    /**
     * @param value After a job run starts, the number of minutes to wait before sending a job run delay notification.
     */
    @JvmName("wbyspiibyxfbhyew")
    public suspend fun notifyDelayAfter(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notifyDelayAfter = mapped
    }

    internal fun build(): JobNotificationPropertyArgs = JobNotificationPropertyArgs(
        notifyDelayAfter = notifyDelayAfter,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/glue/kotlin/inputs/JobNotificationPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.glue.kotlin.inputs

import com.pulumi.aws.glue.inputs.JobNotificationPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property notifyDelayAfter After a job run starts, the number of minutes to wait before sending a job run delay notification.
 */
public data class JobNotificationPropertyArgs(
    public val notifyDelayAfter: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.glue.inputs.JobNotificationPropertyArgs> {
    override fun toJava(): com.pulumi.aws.glue.inputs.JobNotificationPropertyArgs =
        com.pulumi.aws.glue.inputs.JobNotificationPropertyArgs.builder()
            .notifyDelayAfter(notifyDelayAfter?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [JobNotificationPropertyArgs].
 */
@PulumiTagMarker
public class JobNotificationPropertyArgsBuilder internal constructor() {
    private var notifyDelayAfter: Output<Int>? = null

    /**
     * @param value After a job run starts, the number of minutes to wait before sending a job run delay notification.
     */
    @JvmName("shaqxduyscehseme")
    public suspend fun notifyDelayAfter(`value`: Output<Int>) {
        this.notifyDelayAfter = value
    }

    /**
     * @param value After a job run starts, the number of minutes to wait before sending a job run delay notification.
     */
    @JvmName("dfnltraonpmqhgjt")
    public suspend fun notifyDelayAfter(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notifyDelayAfter = mapped
    }

    internal fun build(): JobNotificationPropertyArgs = JobNotificationPropertyArgs(
        notifyDelayAfter = notifyDelayAfter,
    )
}
